/// <reference types="node" />
/// <reference types="node" />
/// <reference types="node" />
import Long from 'long';
import { ServerOptions } from 'https';
import { AddressInfo } from 'net';
import { UUID, UUIDKind } from '../types';
import { Group as GroupData } from '../data/group';
import { signalservice as Proto } from '../../protos/compiled';
import { Server as BaseServer, EnvelopeType, IsSendRateLimitedOptions, ModifyGroupOptions, ModifyGroupResult, ProvisionDeviceOptions, ProvisioningResponse } from '../server/base';
import { Device, DeviceKeys } from '../data/device';
import { PrimaryDevice } from './primary-device';
type TrustRoot = Readonly<{
    privateKey: string;
    publicKey: string;
}>;
type ZKParams = Readonly<{
    secretParams: string;
    publicParams: string;
}>;
export type Config = Readonly<{
    trustRoot?: TrustRoot;
    zkParams?: ZKParams;
    https?: ServerOptions;
    timeout?: number;
    maxStorageReadKeys?: number;
}>;
export type CreatePrimaryDeviceOptions = Readonly<{
    profileName: string;
    contacts?: ReadonlyArray<PrimaryDevice>;
    contactsWithoutProfileKey?: ReadonlyArray<PrimaryDevice>;
}>;
export type PendingProvision = {
    complete(response: PendingProvisionResponse): Promise<Device>;
};
export type PendingProvisionResponse = Readonly<{
    provisionURL: string;
    primaryDevice: PrimaryDevice;
}>;
export type RateLimitOptions = Readonly<{
    source: UUID;
    target: UUID;
}>;
export declare class Server extends BaseServer {
    private readonly config;
    private readonly trustRoot;
    private readonly primaryDevices;
    private readonly knownNumbers;
    private https;
    private emptyAttachment;
    private provisionQueue;
    private provisionResultQueueByCode;
    private provisionResultQueueByKey;
    private manifestQueueByUuid;
    private groupQueueById;
    private rateLimitCountByPair;
    private unregisteredUuids;
    constructor(config?: Config);
    listen(port: number, host?: string): Promise<void>;
    close(): Promise<void>;
    address(): AddressInfo;
    waitForProvision(): Promise<PendingProvision>;
    private waitForStorageManifest;
    waitForGroupUpdate(group: GroupData): Promise<void>;
    createPrimaryDevice({ profileName, contacts, contactsWithoutProfileKey, }: CreatePrimaryDeviceOptions): Promise<PrimaryDevice>;
    createSecondaryDevice(primary: PrimaryDevice): Promise<Device>;
    unregister(primary: PrimaryDevice, uuidKind?: UUIDKind): void;
    register(primary: PrimaryDevice, uuidKind?: UUIDKind): void;
    rateLimit({ source, target }: RateLimitOptions): void;
    stopRateLimiting({ source, target, }: RateLimitOptions): number | undefined;
    getProvisioningResponse(uuid: UUID): Promise<ProvisioningResponse>;
    handleMessage(source: Device | undefined, uuidKind: UUIDKind, envelopeType: EnvelopeType, target: Device, encrypted: Buffer): Promise<void>;
    isUnregistered(uuid: UUID): boolean;
    isSendRateLimited({ source, target, }: IsSendRateLimitedOptions): boolean;
    updateDeviceKeys(device: Device, uuidKind: UUIDKind, keys: DeviceKeys): Promise<void>;
    provisionDevice(options: ProvisionDeviceOptions): Promise<Device>;
    getStorageItems(device: Device, keys: ReadonlyArray<Buffer>): Promise<Array<Proto.IStorageItem> | undefined>;
    modifyGroup(options: ModifyGroupOptions): Promise<ModifyGroupResult>;
    protected onStorageManifestUpdate(device: Device, version: Long): Promise<void>;
    private createQueue;
    private generateNumber;
}
export {};
