/// <reference types="node" />
import { ProtocolAddress, PublicKey } from '@signalapp/libsignal-client';
import { ProfileKeyCommitment } from '@signalapp/libsignal-client/zkgroup';
import { DeviceId, PreKey, RegistrationId, SignedPreKey, UUID, UUIDKind } from '../types';
export type DeviceOptions = Readonly<{
    uuid: UUID;
    pni: UUID;
    number: string;
    deviceId: DeviceId;
    registrationId: RegistrationId;
    pniRegistrationId: RegistrationId;
}>;
export type ChangeNumberOptions = Readonly<{
    number: string;
    pni: UUID;
    pniRegistrationId: RegistrationId;
}>;
export type DeviceKeys = Readonly<{
    identityKey: PublicKey;
    signedPreKey: SignedPreKey;
    preKeys?: ReadonlyArray<PreKey>;
    preKeyIterator?: AsyncIterator<PreKey>;
}>;
export type SingleUseKey = Readonly<{
    identityKey: PublicKey;
    signedPreKey: SignedPreKey;
    preKey: PreKey | undefined;
}>;
export declare class Device {
    readonly uuid: UUID;
    readonly deviceId: DeviceId;
    readonly address: ProtocolAddress;
    accessKey?: Buffer;
    profileKeyCommitment?: ProfileKeyCommitment;
    profileName?: Buffer;
    private keys;
    private privPni;
    private privNumber;
    private privPniAddress;
    private readonly registrationId;
    private pniRegistrationId;
    constructor(options: DeviceOptions);
    get debugId(): string;
    getRegistrationId(uuidKind: UUIDKind): number;
    get pni(): UUID;
    get number(): string;
    get pniAddress(): ProtocolAddress;
    changeNumber({ number, pni, pniRegistrationId, }: ChangeNumberOptions): Promise<void>;
    setKeys(uuidKind: UUIDKind, keys: DeviceKeys): Promise<void>;
    getIdentityKey(uuidKind?: UUIDKind): Promise<PublicKey>;
    popSingleUseKey(uuidKind?: UUIDKind): Promise<SingleUseKey>;
    getSingleUseKeyCount(uuidKind?: UUIDKind): Promise<number>;
    getUUIDByKind(uuidKind: UUIDKind): UUID;
    getUUIDKind(uuid: UUID): UUIDKind;
    getAddressByKind(uuidKind: UUIDKind): ProtocolAddress;
}
