/// <reference types="node" />
import z from 'zod';
export declare const DeviceKeysSchema: z.ZodObject<{
    identityKey: z.ZodString;
    signedPreKey: z.ZodObject<{
        keyId: z.ZodNumber;
        publicKey: z.ZodString;
        signature: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        publicKey: string;
        keyId: number;
        signature: string;
    }, {
        publicKey: string;
        keyId: number;
        signature: string;
    }>;
    preKeys: z.ZodArray<z.ZodObject<{
        keyId: z.ZodNumber;
        publicKey: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        publicKey: string;
        keyId: number;
    }, {
        publicKey: string;
        keyId: number;
    }>, "many">;
}, "strip", z.ZodTypeAny, {
    identityKey: string;
    signedPreKey: {
        publicKey: string;
        keyId: number;
        signature: string;
    };
    preKeys: {
        publicKey: string;
        keyId: number;
    }[];
}, {
    identityKey: string;
    signedPreKey: {
        publicKey: string;
        keyId: number;
        signature: string;
    };
    preKeys: {
        publicKey: string;
        keyId: number;
    }[];
}>;
export type DeviceKeys = z.infer<typeof DeviceKeysSchema>;
export declare const MessageSchema: z.ZodObject<{
    type: z.ZodNumber;
    destinationDeviceId: z.ZodNumber;
    destinationRegistrationId: z.ZodNumber;
    content: z.ZodString;
}, "strip", z.ZodTypeAny, {
    content: string;
    type: number;
    destinationDeviceId: number;
    destinationRegistrationId: number;
}, {
    content: string;
    type: number;
    destinationDeviceId: number;
    destinationRegistrationId: number;
}>;
export type Message = z.infer<typeof MessageSchema>;
export declare const MessageListSchema: z.ZodObject<{
    messages: z.ZodArray<z.ZodObject<{
        type: z.ZodNumber;
        destinationDeviceId: z.ZodNumber;
        destinationRegistrationId: z.ZodNumber;
        content: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        content: string;
        type: number;
        destinationDeviceId: number;
        destinationRegistrationId: number;
    }, {
        content: string;
        type: number;
        destinationDeviceId: number;
        destinationRegistrationId: number;
    }>, "many">;
    timestamp: z.ZodNumber;
}, "strip", z.ZodTypeAny, {
    timestamp: number;
    messages: {
        content: string;
        type: number;
        destinationDeviceId: number;
        destinationRegistrationId: number;
    }[];
}, {
    timestamp: number;
    messages: {
        content: string;
        type: number;
        destinationDeviceId: number;
        destinationRegistrationId: number;
    }[];
}>;
export type MessageList = z.infer<typeof MessageListSchema>;
export declare const RegistrationDataSchema: z.ZodObject<{
    registrationId: z.ZodNumber;
    pniRegistrationId: z.ZodNumber;
}, "strip", z.ZodTypeAny, {
    registrationId: number;
    pniRegistrationId: number;
}, {
    registrationId: number;
    pniRegistrationId: number;
}>;
export declare const GroupStateSchema: z.ZodObject<{
    publicKey: z.ZodType<Uint8Array, z.ZodTypeDef, Uint8Array>;
    version: z.ZodLiteral<0>;
    accessControl: z.ZodObject<{
        attributes: z.ZodNumber;
        members: z.ZodNumber;
        addFromInviteLink: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        members: number;
        attributes: number;
        addFromInviteLink: number;
    }, {
        members: number;
        attributes: number;
        addFromInviteLink: number;
    }>;
    members: z.ZodArray<z.ZodUnknown, "many">;
}, "strip", z.ZodTypeAny, {
    publicKey: Uint8Array;
    accessControl: {
        members: number;
        attributes: number;
        addFromInviteLink: number;
    };
    version: 0;
    members: unknown[];
}, {
    publicKey: Uint8Array;
    accessControl: {
        members: number;
        attributes: number;
        addFromInviteLink: number;
    };
    version: 0;
    members: unknown[];
}>;
export declare const UsernameReservationSchema: z.ZodObject<{
    usernameHashes: z.ZodArray<z.ZodEffects<z.ZodString, Buffer, string>, "many">;
}, "strip", z.ZodTypeAny, {
    usernameHashes: Buffer[];
}, {
    usernameHashes: string[];
}>;
export type UsernameReservation = z.infer<typeof UsernameReservationSchema>;
export declare const UsernameConfirmationSchema: z.ZodObject<{
    usernameHash: z.ZodEffects<z.ZodString, Buffer, string>;
    zkProof: z.ZodEffects<z.ZodString, Buffer, string>;
}, "strip", z.ZodTypeAny, {
    usernameHash: Buffer;
    zkProof: Buffer;
}, {
    usernameHash: string;
    zkProof: string;
}>;
export type UsernameConfirmation = z.infer<typeof UsernameConfirmationSchema>;
