"use strict";
// Copyright 2022 Signal Messenger, LLC
// SPDX-License-Identifier: AGPL-3.0-only
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UsernameConfirmationSchema = exports.UsernameReservationSchema = exports.GroupStateSchema = exports.RegistrationDataSchema = exports.MessageListSchema = exports.MessageSchema = exports.DeviceKeysSchema = void 0;
const zod_1 = __importDefault(require("zod"));
const util_1 = require("../util");
exports.DeviceKeysSchema = zod_1.default.object({
    identityKey: zod_1.default.string(),
    signedPreKey: zod_1.default.object({
        keyId: zod_1.default.number(),
        publicKey: zod_1.default.string(),
        signature: zod_1.default.string(),
    }),
    preKeys: zod_1.default.object({
        keyId: zod_1.default.number(),
        publicKey: zod_1.default.string(),
    }).array(),
});
exports.MessageSchema = zod_1.default.object({
    // NOTE: Envelope.Type
    type: zod_1.default.number(),
    destinationDeviceId: zod_1.default.number(),
    destinationRegistrationId: zod_1.default.number(),
    content: zod_1.default.string(),
});
exports.MessageListSchema = zod_1.default.object({
    messages: exports.MessageSchema.array(),
    timestamp: zod_1.default.number(),
});
exports.RegistrationDataSchema = zod_1.default.object({
    registrationId: zod_1.default.number(),
    pniRegistrationId: zod_1.default.number(),
});
exports.GroupStateSchema = zod_1.default.object({
    publicKey: zod_1.default.instanceof(Uint8Array),
    version: zod_1.default.literal(0),
    accessControl: zod_1.default.object({
        attributes: zod_1.default.number(),
        members: zod_1.default.number(),
        addFromInviteLink: zod_1.default.number(),
    }),
    members: zod_1.default.unknown().array().min(1),
});
exports.UsernameReservationSchema = zod_1.default.object({
    usernameHashes: zod_1.default.string().transform(util_1.fromURLSafeBase64).array().min(1).max(20),
});
exports.UsernameConfirmationSchema = zod_1.default.object({
    usernameHash: zod_1.default.string().transform(util_1.fromURLSafeBase64),
    zkProof: zod_1.default.string().transform(util_1.fromURLSafeBase64),
});
